import pandas as pd
def topsis(df,weights,impacts):
    vjp=[]
    vjn=[]
    for i in range(1,df.shape[1]):
        df.iloc[:,i]=pd.to_numeric(df.iloc[:,i])
        s=sum(df.iloc[:,i]**2)**0.5
        for j in range(df.shape[0]):
            df.iloc[j,i]=round(df.iloc[j,i]/s,4)
    for i in range(1,df.shape[1]):
        df.iloc[:,i]=round(df.iloc[:,i]*weights[i-1],4)   
    for i in range(1,df.shape[1]):
        if impacts[i-1]=='+':
            vjp.append(max(df.iloc[:,i]))
            vjn.append(min(df.iloc[:,i]))
        else:
            vjn.append(max(df.iloc[:,i]))
            vjp.append(min(df.iloc[:,i]))
# print(vjp,vjn)
    for i in range(df1.shape[0]):
        df.loc[i,'sj+']=sum((df.iloc[i,1:df1.shape[1]]-vjp)**2)**0.5
    for i in range(df1.shape[0]):
        df.loc[i,'sj-']=sum((df.iloc[i,1:df1.shape[1]]-vjn)**2)**0.5
# print(df)
    df['Topsis Score']=round(df['sj-']/(df['sj+']+df['sj-']),2)
    df['Rank']=df['Topsis Score'].rank(ascending=False).astype('int')
    return df


import setuptools
 
# with open("README.md", "r") as fh:
#     long_description = fh.read()
 
setuptools.setup(
    #Here is the module name.
    name="TOPSISPANKAJ",
 
    #version of the module
    version="0.0.4",
 
    #Name of Author
    author="Pankaj Gupta",
 
    #your Email address
    author_email="pankaj140699@gmail.com",
 
    #Small Description about module
    description="Multiple Criteria Decision Making using Topsis",
 
    long_description="It will give a Topsis score",
 
    #Specifying that we are using markdown file for description
    # long_description_content_type="text/markdown",

    #Any link to reach this module, if you have any webpage or github profile
    # url="https://github.com/Pushkar-Singh-14/",
    packages=['TOPSISPANKAJ'],
    install_requires=['pandas']
    #classifiers like program is suitable for python3, just leave as it is.
    # classifiers=[
    #     "Programming Language :: Python :: 3",
    #     "License :: OSI Approved :: MIT License",
    #     "Operating System :: OS Independent",
    # ],
)